==> voiceflow-1.0.0.tar.gz: voiceflow/modules/voiceflow_index/src/Controller/VoiceflowIndexController.php <==
<?php

namespace Drupal\voiceflow_index\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DateFormatterInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Voiceflow Index Controller.
 *
 * Generates an XML report of nodes with 'voiceflow_index' enabled.
 */
final class VoiceflowIndexController extends ControllerBase {

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * Constructs a VoiceflowIndexController object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   */
  public function __construct(DateFormatterInterface $date_formatter) {
    $this->dateFormatter = $date_formatter;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('date.formatter')
    );
  }

  /**
   * Generates the index XML report.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The XML response.
   */
  public function generateIndex() {
    // Get the published nodes with 'voiceflow_index' enabled.
    $query = $this->entityTypeManager()->getStorage('node')->getQuery();
    $query->condition('status', 1)
      ->condition('voiceflow_index', 1);
    $query->accessCheck(TRUE);
    $nids = $query->execute();

    $xml_output = new \SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><urlset/>');
    $xml_output->addAttribute('xmlns', 'http://www.sitemaps.org/schemas/sitemap/0.9');
    $xml_output->addAttribute('xmlns:xhtml', 'http://www.w3.org/1999/xhtml');

    $nodes = $this->entityTypeManager()->getStorage('node')->loadMultiple($nids);
    foreach ($nodes as $node) {
      // URL Location.
      $canonical_url = $node->toUrl('canonical', ['absolute' => TRUE])->toString();
      $url_element = $xml_output->addChild('url');
      $url_element->addChild('loc', $canonical_url);
      // Translation set.
      $translations = $node->getTranslationLanguages();
      foreach ($translations as $langcode => $language) {
        $translated_node = $node->getTranslation($langcode);
        $translation_url = $translated_node->toUrl('canonical', ['absolute' => TRUE])->toString();

        $link_element = $url_element->addChild('link');
        $link_element->addAttribute('rel', 'alternate');
        $link_element->addAttribute('hreflang', $langcode);
        $link_element->addAttribute('href', $translation_url);
      }
      // Last modification date.
      $last_mod = $this->dateFormatter->format($node->getChangedTime() ?? time(), 'custom', 'Y-m-d\TH:i:sP');
      $url_element->addChild('lastmod', $last_mod);
    }

    // Configure the response as XML.
    $response = new Response($xml_output->asXML() ?: '');
    $response->headers->set('Content-Type', 'application/xml');
    return $response;
  }

}

==> voiceflow-1.0.1.tar.gz: voiceflow/modules/voiceflow_index/src/Controller/VoiceflowIndexController.php <==
<?php

namespace Drupal\voiceflow_index\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DateFormatterInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Voiceflow Index Controller.
 *
 * Generates an XML report of nodes with 'voiceflow_index' enabled.
 */
final class VoiceflowIndexController extends ControllerBase {

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * Constructs a VoiceflowIndexController object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   */
  public function __construct(DateFormatterInterface $date_formatter) {
    $this->dateFormatter = $date_formatter;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('date.formatter')
    );
  }

  /**
   * Generates the index XML report.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The XML response.
   */
  public function generateIndex() {
    // Get the published nodes with 'voiceflow_index' enabled.
    $query = $this->entityTypeManager()->getStorage('node')->getQuery();
    $query->condition('status', 1)
      ->condition('voiceflow_index', 1);
    $query->accessCheck(TRUE);
    $nids = $query->execute();

    $xml_output = new \SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><urlset/>');
    $xml_output->addAttribute('xmlns', 'http://www.sitemaps.org/schemas/sitemap/0.9');
    $xml_output->addAttribute('xmlns:xhtml', 'http://www.w3.org/1999/xhtml');

    $nodes = $this->entityTypeManager()->getStorage('node')->loadMultiple($nids);
    foreach ($nodes as $node) {
      $languages = $node->getTranslationLanguages();
      foreach ($languages as $langcode => $language) {
        $node_translation = $node->getTranslation($langcode);
        // URL Location.
        $translation_url = $node_translation->toUrl('canonical', ['absolute' => TRUE])->toString();
        $url_element = $xml_output->addChild('url');
        $url_element->addChild('loc', $translation_url);
        // Translation set.
        foreach ($languages as $langcode => $language) {
          $alt_node_translation = $node->getTranslation($langcode);
          $alt_translation_url = $alt_node_translation->toUrl('canonical', ['absolute' => TRUE])->toString();

          $link_element = $url_element->addChild('link');
          $link_element->addAttribute('rel', 'alternate');
          $link_element->addAttribute('hreflang', $langcode);
          $link_element->addAttribute('href', $alt_translation_url);
        }
        // Last modification date.
        $last_mod = $this->dateFormatter->format($node_translation->getChangedTime() ?? time(), 'custom', 'Y-m-d\TH:i:sP');
        $url_element->addChild('lastmod', $last_mod);
      }
    }

    // Configure the response as XML.
    $response = new Response($xml_output->asXML() ?: '');
    $response->headers->set('Content-Type', 'application/xml');
    return $response;
  }

}
